#
# spec file for package updatecli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           updatecli
Version:        0.99.0
Release:        1.1
Summary:        A Declarative Dependency Management tool
License:        Apache-2.0
URL:            https://github.com/updatecli/updatecli
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.24.1
BuildRequires:  zsh

%description
Updatecli is a tool used to apply file update strategies. Designed to be used
from everywhere, each application "run" detects if a value needs to be updated
using a custom strategy then apply changes according to the strategy.

You describe your update strategy in a file then you run updatecli to it.

Updatecli reads a yaml or a go template configuration file, then works into
three stages.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
GO_VERSION="$(go version)"
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" \
   -X \"github.com/updatecli/updatecli/pkg/core/version.GoVersion=${GO_VERSION}\" \
   -X github.com/updatecli/updatecli/pkg/core/version.Version=v%{version} \
   -X github.com/updatecli/updatecli/pkg/core/version.BuildTime=${BUILD_DATE}" \
   -o bin/%{name} ./main.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} %{buildroot}/%{_bindir}/%{name}

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.adoc
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Mon May  5 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.99.0:
  * Features
  - feat(core): export pipeline report to disk [experimental]
    @olblak (#4898)
  - feat(autodiscovery): Add Nomad integration @olblak (#4957)
  - feat(autodiscovery/githubaction): digest should allow
    handling of main @loispostula (#4959)
  - feat(autodiscovery/precommit): add support for digest in
    precommit autodiscovery @loispostula (#4928)
  - feat: add quote/unquote transformers @loispostula (#4870)
  * Bug Fixes
  - fix: github action e2e test branch @olblak (#4975)
  - fix(yaml): improve target change detection logic @omissis
    (#4864)
  - fix(autodiscovery/flux): don't ignore flux helmrelease update
    when using an actionID @olblak (#4866)
  * Maintenance
  - deps(go): bump module github.com/drone/go-scm to v1.40.1
    @updateclibot[bot] (#5003)
  - fix(autodiscovery/githubaction): replace deprecated key hash
    by hashtag @olblak (#4982)
  - deps(go): bump module github.com/yuin/goldmark to v1.7.11
    @updateclibot[bot] (#4949)
  - deps(github/action): bump all dependencies @updateclibot[bot]
    (#4938)
  - deps(go): bump module
    github.com/testcontainers/testcontainers-go to v0.37.0
    @updateclibot[bot] (#4937)
  - deps: bump golangci-lint to v2.1.5 @updateclibot[bot] (#4909)
  - deps(go): bump module github.com/beevik/etree to v1.5.1
    @updateclibot[bot] (#4914)
  - deps(go): bump module github.com/aws/aws-sdk-go to v1.55.7
    @updateclibot[bot] (#4905)
  - deps: update ubuntu version used in Update
    release-drafter.yml @olblak (#4888)
  - deps(go): bump module github.com/yuin/goldmark to v1.7.10
    @updateclibot[bot] (#4853)
  - deps(go): bump module
    github.com/hashicorp/terraform-registry-address to v0.2.5
    @updateclibot[bot] (#4844)
  - deps(go): bump module github.com/go-git/go-git/v5 to v5.16.0
    @updateclibot[bot] (#4836)
* Mon Apr 14 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.98.0:
  * Features
  - feat(autodiscovery): add support for k8s initContainers
    (#4569) @luilegeant (#4570)
  * Bug Fixes
  - fix(udash): correctly handle error if udash doesn't exist
    @olblak (#4767)
  * Maintenance
  - deps(go): bump module github.com/go-git/go-git/v5 to v5.15.0
    @updateclibot[bot] (#4810)
  - deps(go): bump module github.com/drone/go-scm to v1.40.0
    @updateclibot[bot] (#4802)
  - deps(go): bump module helm.sh/helm/v3 to v3.17.3
    @updateclibot[bot] (#4791)
  - deps: Update ubuntu runner for codeql-analysis.yml @olblak
    (#4768)
  - deps(go): bump module golang.org/x/net to v0.39.0
    @updateclibot[bot] (#4757)
  - deps(go): bump module golang.org/x/oauth2 to v0.29.0
    @updateclibot[bot] (#4747)
  - deps(go): bump module cuelang.org/go to v0.12.1
    @updateclibot[bot] (#4737)
  - deps: Bump Golang version to 1.24.2 @updateclibot[bot]
    (#4719)
  - deps(go): bump module github.com/goccy/go-yaml to v1.17.1
    @updateclibot[bot] (#4721)
  - deps(github/action): bump all dependencies @updateclibot[bot]
    (#4718)
  - deps: use one PR per golang major update @olblak (#4560)
  - deps: automerge golang patch update version @olblak (#4559)
  - fix(updatecli): ignore some Go module version update for
    github.com/hashicorp/hcl/v2 @olblak (#4699)
  - deps: bump github.com/minamijoyo/hcledit to v0.2.17 @olblak
    (#4585)
  - deps(go): bump module github.com/zclconf/go-cty to v1.16.2
    @updateclibot[bot] (#4668)
  - chore(deps): Bump github.com/golang-jwt/jwt/v5 from 5.2.1 to
    5.2.2 @dependabot[bot] (#4511)
  - ci: update to golangci v2 configuration && fix reported
    linting issues @olblak (#4568)
  - deps(github/action): bump all dependencies @updateclibot[bot]
    (#4555)
  - deps: bump golangci-lint to v2.0.2 @updateclibot[bot] (#4550)
  * Documentation
  - doc: add Criteo to ADOPTERS.md @alikhil (#4765)
  - doc: add Mbrella ADOPTERS.md @loispostula (#4738)
* Mon Mar 31 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to version 0.97.0:
  * Features
  - feat: Support key title for githubrelease source, condition
    @viccuad (#4528)
  * Maintenance
  - deps(go): bump module golang.org/x/net to v0.38.0
    @updateclibot[bot] (#4540)
  - deps(go): bump module
    github.com/testcontainers/testcontainers-go to v0.36.0
    @updateclibot[bot] (#4535)
  - deps(github/action): bump all dependencies @updateclibot[bot]
    (#4513)
* Mon Mar 24 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.96.0:
  * Features
  - feat: support basic authorization for non-oci private helm
    repos @alikhil (#4494)
  - feat: default yaml plugin should also support adding comments
    @olblak (#4492)
  - feat(shell): set default shell environments variable @olblak
    (#4426)
  - feat: allow to specify assignees & reviewers to github
    pullrequest @olblak (#4418)
  - feat(flux): support multiple YAML documents per file @Antvirf
    (#4429)
  - feat: gitlab support authorization with bearer token @alikhil
    (#4432)
  - feat(golang/autodiscovery): make it easier to restrict to go
    module orr go version update @olblak (#4427)
  * Maintenance
  - chore(deps): Bump github.com/containerd/containerd from
    1.7.24 to 1.7.27 @dependabot[bot] (#4467)
  - deps: bump golangci-lint to v1.64.8 @updateclibot[bot]
    (#4483)
  - deps(go): bump module github.com/BurntSushi/toml to v1.5.0
    @updateclibot[bot] (#4471)
  - deps(go): bump module github.com/goccy/go-yaml to v1.16.0
    @updateclibot[bot] (#4461)
  - deps(go): bump module github.com/spf13/afero to v1.14.0
    @updateclibot[bot] (#4435)
  - deps(go): bump module helm.sh/helm/v3 to v3.17.2
    @updateclibot[bot] (#4417)
  - deps: Bump Golang version to 1.24.1 @olblak (#4410)
* Wed Mar 12 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.95.1:
  * ci(release): Create a token for multiple repositories in the
    current owner's installation (#4367)
  * chore: deps: bump golangci-lint in GitHub Action to v1.64.7
    (#4383)
  * deps: bump updatecli version to v0.95.0 (#4368)
  * fix: helm changelog tests (#4372)
* Tue Mar 11 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.95.0:
  * fix: only update github action version in .github/workflows
    (#4358)
  * deps(go): bump module golang.org/x/oauth2 to v0.28.0 (#4345)
  * feat: gitlab/mergerequest support updating existing MR to merge
    action reports (#4339)
  * fix: generated autodiscovery pipeline uses original action id
    (#4340)
  * fix: helm changelogs from github releases (#4330)
  * deps(go): bump module github.com/fluxcd/source-controller/api
    to v1.5.0 (#4316)
  * chore: deps: bump golangci-lint in GitHub Action to v1.64.6
    (#4298)
  * deps(go): bump module golang.org/x/net to v0.37.0 (#4303)
  * chore: deps(github-action): Bump Golang version to 1.24.1
    (#4294)
  * deps(go): bump module github.com/opencontainers/image-spec to
    v1.1.1 (#4291)
  * chore: clean: go mod tidy (#4273)
  * deps(go): bump module golang.org/x/mod to v0.24.0 (#4180)
  * feat: get helm changelog from annotations and github release
    (#4164)
  * fix: ensure the directory exists before writing to file (#4170)
  * deps(go): bump module github.com/google/go-github/v69 to
    v69.2.0 (#4146)
  * deps(go): bump module github.com/go-git/go-git/v5 to v5.14.0
    (#4070)
  * feat: changelog should display the delta between a source and a
    target version (#3888)
  * fix: correctly set http headers in http plugin (#4025)
  * chore(deps): Bump github.com/go-jose/go-jose/v4 from 4.0.4 to
    4.0.5 (#4014)
  * deps(go): bump module golang.org/x/text to v0.22.0 (#3997)
  * deps(go): bump module github.com/beevik/etree to v1.5.0 (#3975)
  * deps(go): bump module github.com/spf13/cobra to v1.9.1 (#3986)
  * deps(go): bump module github.com/goccy/go-yaml to v1.15.23
    (#3976)
  * deps: bump updatecli version to v0.94.1 (#3968)
* Thu Feb 20 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.94.1:
  * Bug Fixes
  - fix: use the right action configuration in autodiscovery
    @olblak (#3956)
  * Maintenance
  - deps(go): bump module github.com/drone/go-scm to v1.39.2
    @updateclibot[bot] (#3943)
* Wed Feb 19 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.94.0:
  * Features
  - feat: set oauth2 as default github username when username is
    not provided. @treezio (#3920)
  - feat: autodiscovery set default action title @olblak (#3797)
  * Bug Fixes
  - fix(maven): check all configured repositories before
    returning an error @lorenzobenvenuti (#3903)
  * Maintenance
  - deps: bump golangci-lint to v1.64.5 @updateclibot[bot]
    (#3878)
  - deps(go): bump module golang.org/x/mod @updateclibot[bot]
    (#3869)
  - deps(go): bump module helm.sh/helm/v3 @updateclibot[bot]
    (#3836)
  - deps: bump golangci-lint to v1.64.2 @updateclibot[bot]
    (#3816)
  - deps(go): bump module golang.org/x/oauth2 @updateclibot[bot]
    (#3807)
  - deps(go): bump module github.com/goccy/go-yaml
    @updateclibot[bot] (#3799)
  - deps: Bump Golang version to 1.23.6 @updateclibot[bot]
    (#3785)
  - feat: switch to official github action to obtain app token
    @loispostula (#3774)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.93.1:
  * deps(go): bump module github.com/goccy/go-yaml (#3760)
  * deps(go): bump module cuelang.org/go (#3750)
  * deps(go): bump module github.com/spf13/afero (#3731)
  * deps(go): bump module github.com/aws/aws-sdk-go (#3737)
  * deps(go): bump module github.com/goccy/go-yaml (#3723)
  * fix: autodiscovery precommit not working if default branch of
    remote hook is not main (#3715)
  * deps: bump updatecli version to v0.93.0 (#3699)
* Fri Feb  7 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.93.0:
  * deps(go): bump module helm.sh/helm/v3 (#3685)
  * deps(go): bump module github.com/zclconf/go-cty (#3679)
  * chore: rewrite autodiscovery dockercompoes plugin comment
    (#3660)
  * chore: update conferences in README (#3661)
  * fix: hide username/password from URL in log message (#3659)
  * feat: github action autodiscovyer support docker (#3633)
  * deps(go): bump module github.com/go-git/go-git/v5 (#3638)
  * deps: Bump Golang version to 1.23.5 (#3616)
  * deps(go): bump module github.com/zclconf/go-cty (#3602)
  * deps(go): bump module github.com/goccy/go-yaml (#3606)
  * deps(go): bump module github.com/google/go-containerregistry
    (#3591)
  * deps(go): bump module github.com/goccy/go-yaml (#3584)
  * fix(githubaction): correctly ignore relative path action
    (#3562)
  * fix(gittag): always return lightweight git tag (#3561)
  * deps(go): bump module
    github.com/hashicorp/terraform-registry-address (#3547)
  * deps: bump updatecli version to v0.92.0 (#3539)
* Mon Jan 13 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.92.0:
  * Features
  - githubaction autodiscovery should allow for pinning version
    to commit hash @loispostula (#3508)
  - improvement(httpclient): add support for http proxy in retry
    client @ryancurrah (#3516)
  - feat: add versionfilter of kind lexicographical @acobaugh
    (#3371)
  - feat: add versionfilter of kind time @olblak (#3405)
  * Bug Fixes
  - fix(autodiscovery/helm): correctly handle ignore/only rule
    @olblak (#3501)
  - fix(autodiscovery/dockercompose): correctly set arch @olblak
    (#3500)
  - fix(helm): retrieve correct helm chart changelog based on a
    version @olblak (#3489)
  - fix(helm): Protect against undefined sourceSpec
    @kuisathaverat (#3369)
  - fix(autodiscovery/argocd): ArgoCD autodiscovery for OCI
    registry @dshmelev (#3461)
  - fix!(versionfilter): preserve original version for
    regex/semver @mcwarman (#3404)
  - fix: use latest when tag is not set in autodiscover
    @kuisathaverat (#3370)
  * Maintenance
  - refactor(git): git error messages @olblak (#3460)
  - refactor(json): improving json error message @olblak (#3458)
  - Adds devcontainer @btrepp (#2807)
  - deps(go): bump module
    github.com/testcontainers/testcontainers-go @updateclibot
    (#3517)
  - deps(go): bump module github.com/go-git/go-git/v5
    @updateclibot (#3447)
  - deps(go): bump module golang.org/x/oauth2 @updateclibot
    (#3430)
  - deps(go): bump module github.com/zclconf/go-cty @updateclibot
    (#3431)
  - deps(go): bump module github.com/goccy/go-yaml @updateclibot
    (#3394)
  - deps(go): bump module github.com/invopop/jsonschema
    @updateclibot (#3387)
  - deps(go): bump module github.com/go-git/go-git/v5
    @updateclibot (#3375)
* Fri Dec 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.91.0:
  * feat: add version filter regex-semver (#3347)
  * feat(autodiscovery): support kubernetes cronjob (#3346)
  * deps: bump updatecli version to v0.90.0 (#3338)
* Fri Dec 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.90.0:
  * deps(go): bump module github.com/goccy/go-yaml (#3324)
  * Merge commit from fork
  * chore(deps): Bump codecov/codecov-action from 4 to 5 (#3052)
  * chore(deps): Bump filippo.io/age from 1.2.0 to 1.2.1 (#3314)
  * deps(go): bump module cuelang.org/go (#3313)
  * deps(go): bump module helm.sh/helm/v3 (#3306)
  * deps(go): bump module github.com/goccy/go-yaml (#3298)
  * feat(maven): Support settings.xml for setting credentials and
    mirrors (#3270)
  * feat: allow to deepmerge multiple values file (#3291)
  * Update SECURITY.md (#3277)
  * chore(deps): Bump golang.org/x/crypto from 0.29.0 to 0.31.0
    (#3271)
  * deps(go): bump module github.com/goccy/go-yaml (#3267)
  * deps: bump updatecli version to v0.89.0 (#3263)
* Mon Dec  9 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.89.0:
  * deps(go): bump module golang.org/x/text (#3255)
  * deps(go): bump module github.com/goccy/go-yaml (#3248)
  * deps: Bump Golang version to 1.23.4 (#3237)
  * feat: display action result in Summary (#3223)
  * deps(go): bump module github.com/getsops/sops/v3 (#3232)
  * deps(go): bump module github.com/drone/go-scm (#3220)
  * fix(stash): use markdown body instead of html (#3224)
  * deps: bump updatecli version to v0.88.1 (#3211)
* Mon Dec  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.88.1:
  * feat: allow to login on Udash without auth enabled (#3203)
  * deps: bump updatecli version to v0.88.0 (#3176)
  * fix: display target console output in Updatecli report (#3190)
  * deps(go): bump module github.com/zclconf/go-cty (#3182)
* Wed Nov 27 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.88.0:
  * doc: add mermaid to manifest show command output (#3173)
  * fix: flavour to flavor
  * feat: add Pipeline graph to issue template
  * feat: add mermaid graph flavour
  * fix: only look at target when target has dependsonchange: true
    (#3160)
  * deps: bump updatecli version to v0.87.0 (#3148)
  * doc(e2e tests) add a minimalistic documentation (#1120)
* Tue Nov 26 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.87.0:
  * deps: use go-scm upstream project (#3146)
  * chore: deps(go): bump module github.com/drone/go-scm to v1.39.0
    (#3137)
  * deps(go): bump module cuelang.org/go (#3131)
  * deps(go): bump module helm.sh/helm/v3 (#3126)
  * deps(go): bump module github.com/stretchr/testify (#3119)
  * deps(go): bump module github.com/goccy/go-yaml (#3111)
  * deps(go): bump module github.com/Masterminds/semver/v3 (#3101)
  * chore: deps(go): bump module github.com/drone/go-scm to v1.38.9
    (#3091)
  * feat(autodiscovery/helm): allow to set target.SkipPackaging for
    helmchart (#3062)
  * fix: message for golang update in go.mod (#3068)
  * feat(temurin): introduces condition to check for Adoptium
    releases existence (#3063)
  * deps(go): bump module github.com/hashicorp/hcl/v2 (#3055)
  * deps(go): bump module github.com/goccy/go-yaml (#3044)
  * deps: Bump Golang version to 1.23.3 (#3031)
  * deps(go): bump module golang.org/x/text (#3027)
  * deps(go): bump module golang.org/x/oauth2 (#3011)
  * deps(go): bump module golang.org/x/mod (#3012)
  * fix: print Updatecli log to stdout instead of sterr (#2997)
  * deps(go): bump module github.com/goccy/go-yaml (#2989)
  * deps: bump updatecli version to v0.86.1 (#2979)
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.86.1:
  * fix: source block can be nil (#2977)
  * deps: bump updatecli version to v0.86.0 (#2963)
* Mon Nov  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.86.0:
  * feat: add GitHub action autodiscovery plugin (#1964)
  * deps(go): bump module github.com/goccy/go-yaml (#2956)
  * deps(go): bump module github.com/goccy/go-yaml (#2949)
  * chore(deps): Bump anchore/sbom-action from 0.17.3 to 0.17.6
    (#2941)
  * feat(gitbranch): Add git url param to gitbranch plugin (#2850)
  * fix(gittag): allow to specify the sourcebranch where to create
    the tag (#2926)
  * deps(go): bump module github.com/goccy/go-yaml (#2924)
  * fix(temurin) use OS and architecture to filter responses when
    retrieving versions (#2917)
  * fix(temurin) fail explicitly when specifying condition or
    target of kind 'temurin' (#2916)
  * feat(gittag): Add git url param to gittag plugin (#2848)
  * deps(go): bump module cuelang.org/go (#2902)
  * feat: detect auto-debug in the CI (#2822)
  * deps(updatecli/policies): bump all policies (#2712)
  * feat(scm): add bitbucket cloud scm and action support (#2847)
  * fix: show pipeline as skipped if all target are skipped (#2849)
  * deps(go): bump module github.com/fatih/color (#2875)
  * deps(go): bump module github.com/yuin/goldmark (#2870)
  * deps(go): bump module
    github.com/testcontainers/testcontainers-go (#2861)
  * deps(go): bump module helm.sh/helm/v3 (#2859)
  * fix: disabling temurin s390x test (#2852)
  * feat(core/pipeline): allow dependency across
    source/conditions/targets (#2800)
  * fix(doc): Typos (#2824)
  * chore(deps): Bump anchore/sbom-action from 0.17.2 to 0.17.3
    (#2823)
  * chore: deps(go): bump module github.com/drone/go-scm to v1.38.8
    (#2812)
  * Fix bug when gitea request fails (#2806)
  * deps: bump updatecli version to v0.85.0 (#2794)
* Fri Oct 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.85.0:
  * deps(go): bump module github.com/getsops/sops/v3 (#2787)
  * chore(deps): Bump sigstore/cosign-installer from 3.6.0 to 3.7.0
    (#2771)
  * feat(autodiscovery/precommit): initial implementation (#2773)
  * feat: dockerfile autodiscovery should ignore stage name and
    scratch (#2752)
  * deps(go): bump module golang.org/x/text (#2772)
  * Disable spellcheck (#2765)
  * chore(gha): update check-spelling to 0.0.22 (#2759)
  * deps: Bump Golang version to 1.23.2 (#2753)
  * deps: bump updatecli version to v0.84.1 (#2746)
* Wed Oct  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.84.1:
  * Fix prerelease semver filtering when current version is stable
    (#2736)
  * fix(prow/e2e): ignore broken image and use updatecli-test
    (#2737)
  * deps(go): bump module github.com/fluxcd/source-controller/api
    (#2729)
  * chore: deps(go): bump module github.com/drone/go-scm to v1.38.7
    (#2724)
  * deps(go): bump module helm.sh/helm/v3 (#2719)
  * deps(go): bump module helm.sh/helm/v3 (#2713)
  * chore: deps(go): bump module github.com/drone/go-scm to v1.38.6
    (#2706)
  * deps(go): bump module github.com/beevik/etree (#2702)
  * deps(go): bump module github.com/aws/aws-sdk-go (#2691)
  * chore: update golang patch one at a time (#2689)
  * deps(go): bump module github.com/getsops/sops/v3 (#2684)
  * deps: Bump Golang version to 1.23.1 (#2672)
  * deps(go): bump module
    github.com/testcontainers/testcontainers-go (#2677)
  * deps: bump docker dependencies (#2671)
  * deps(go): bump module golang.org/x/mod (#2669)
  * deps(go): bump module golang.org/x/text (#2664)
  * deps(go): bump module golang.org/x/oauth2 (#2658)
  * chore(deps): Bump github.com/opencontainers/runc from 1.1.12 to
    1.1.14 (#2647)
  * chore(text): switch to httpclient (#2622)
  * chore(spelling): add end of line new line (#2632)
  * fix spelling warning (#2629)
  * deps: bump updatecli version to v0.84.0 (#2623)
* Tue Sep 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package updatecli: a declarative dependency management tool
